==> qtjambi-qt3drender-6.5.7-sources.jar: io/qt/qt3d/render/QSetFence.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>FrameGraphNode used to insert a fence in the graphics command stream</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html">Qt3DRender::QSetFence</a></code></p>
 */
public class QSetFence extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSetFence.class);
    
    /**
     * <p>Java wrapper for Qt enum <code>Qt3DRender::QSetFence::HandleType</code></p>
     */
    public enum HandleType implements QtEnumerator {
        /**
         * <p>Representing <code>Qt3DRender::<wbr/>QSetFence::<wbr/>NoHandle</code></p>
         */
        NoHandle(0),
        /**
         * <p>Representing <code>Qt3DRender::<wbr/>QSetFence::<wbr/>OpenGLFenceId</code></p>
         */
        OpenGLFenceId(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private HandleType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        @Override
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull HandleType resolve(int value) {
            switch (value) {
            case 0: return NoHandle;
            case 1: return OpenGLFenceId;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::<wbr/>handleChanged(QVariant)</a></code></p>
     */
    @QtPropertyNotify(name="handle")
    public final @NonNull Signal1<java.lang.Object> handleChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::<wbr/>handleTypeChanged(Qt3DRender::QSetFence::HandleType)</a></code></p>
     */
    @QtPropertyNotify(name="handleType")
    public final @NonNull Signal1<io.qt.qt3d.render.QSetFence.@NonNull HandleType> handleTypeChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QSetFence::<wbr/>QSetFence(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QSetFence(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSetFence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::<wbr/>handle()const</a></code></p>
     */
    @QtPropertyReader(name="handle")
    @QtUninvokable
    public final java.lang.Object handle(){
        return handle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object handle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::<wbr/>handleType()const</a></code></p>
     */
    @QtPropertyReader(name="handleType")
    @QtUninvokable
    public final io.qt.qt3d.render.QSetFence.@NonNull HandleType handleType(){
        return io.qt.qt3d.render.QSetFence.HandleType.resolve(handleType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int handleType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSetFence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QSetFence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QSetFence instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSetFence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSetFence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #handle()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.Object getHandle() {
        return handle();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #handleType()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QSetFence.@NonNull HandleType getHandleType() {
        return handleType();
    }
}

==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QSetFence.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>FrameGraphNode used to insert a fence in the graphics command stream</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html">Qt3DRender::QSetFence</a></code></p>
 */
public class QSetFence extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSetFence.class);
    
    /**
     * <p>Java wrapper for Qt enum <code>Qt3DRender::QSetFence::HandleType</code></p>
     */
    public enum HandleType implements QtEnumerator {
        /**
         * <p>Representing <code>Qt3DRender::<wbr>QSetFence::<wbr>NoHandle</code></p>
         */
        NoHandle(0),
        /**
         * <p>Representing <code>Qt3DRender::<wbr>QSetFence::<wbr>OpenGLFenceId</code></p>
         */
        OpenGLFenceId(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private HandleType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull HandleType resolve(int value) {
            switch (value) {
            case 0: return NoHandle;
            case 1: return OpenGLFenceId;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::<wbr>handleChanged(QVariant)</a></code></p>
     */
    @QtPropertyNotify(name="handle")
    public final @NonNull Signal1<java.lang.Object> handleChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::<wbr>handleTypeChanged(Qt3DRender::QSetFence::HandleType)</a></code></p>
     */
    @QtPropertyNotify(name="handleType")
    public final @NonNull Signal1<io.qt.qt3d.render.QSetFence.@NonNull HandleType> handleTypeChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QSetFence::<wbr>QSetFence(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QSetFence(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSetFence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::<wbr>handle()const</a></code></p>
     */
    @QtPropertyReader(name="handle")
    @QtUninvokable
    public final java.lang.Object handle(){
        return handle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object handle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::<wbr>handleType()const</a></code></p>
     */
    @QtPropertyReader(name="handleType")
    @QtUninvokable
    public final io.qt.qt3d.render.QSetFence.@NonNull HandleType handleType(){
        return io.qt.qt3d.render.QSetFence.HandleType.resolve(handleType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int handleType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSetFence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QSetFence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QSetFence instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSetFence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSetFence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #handle()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.Object getHandle() {
        return handle();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #handleType()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QSetFence.@NonNull HandleType getHandleType() {
        return handleType();
    }
}
